﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Windows.Chart;

namespace MultiSelection
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            Loaded += new RoutedEventHandler(MainWindow_Loaded);
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            ObservableCollection<Data> dataSource = new ObservableCollection<Data>()
            {
                new Data(){ Value=60 },
                new Data(){ Value=80 },
                new Data(){ Value=30 },
                new Data(){ Value=90 },
                new Data(){ Value=70 }
            };
            s1.DataSource = dataSource;
            s1.DataMapping = "Value=Value";
        }

        private void xamChart1_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            XamChart theChart = (XamChart)sender;
            HitTestArgs hit = theChart.HitTest(e);
            DataPoint dp = hit.SelectedObject as DataPoint;
            if (null != dp)
            {
                bool isSelected = (bool)dp.GetValue(DataPointAdvisor.IsSelectedProperty);
                if (isSelected)
                {
                    dp.SetValue(DataPointAdvisor.IsSelectedProperty, false);
                }
                else
                {
                    dp.SetValue(DataPointAdvisor.IsSelectedProperty, true);
                }
            }
           
        }
    }
    public class Data
    {
        public double Value { get; set; }
    }

    public class DataPointAdvisor : DependencyObject
    {
        public DataPointAdvisor()
        {
            SetValue(SelectedPointsProperty, new ObservableCollection<DataPoint>());
        }

        #region IsSelected

        public static bool GetIsSelected(DependencyObject obj)
        {
            return (bool)obj.GetValue(IsSelectedProperty);
        }

        public static void SetIsSelected(DependencyObject obj, bool value)
        {
            obj.SetValue(IsSelectedProperty, value);
        }

        // Using a DependencyProperty as the backing store for IsSelected.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty IsSelectedProperty =
            DependencyProperty.RegisterAttached("IsSelected", typeof(bool), typeof(DataPointAdvisor), 
             new FrameworkPropertyMetadata(false,
                    new PropertyChangedCallback(OnIsSelectedChanged)));

        private static void OnIsSelectedChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            DataPoint dp = d as DataPoint;
            XamChart chart = dp.Tag as XamChart;
            if (chart != null)
            {
                ObservableCollection<DataPoint> selectedPoints = chart.GetValue(DataPointAdvisor.SelectedPointsProperty) as ObservableCollection<DataPoint>;

                if ((bool)e.NewValue)
                {
                    selectedPoints.Add(dp);
                }
                else
                {
                    selectedPoints.Remove(dp);
                }
            }
        }

        #endregion IsSelected

        #region SelectedPoints

        public static readonly DependencyProperty SelectedPointsProperty =
            DependencyProperty.RegisterAttached("SelectedPoints", typeof(ObservableCollection<DataPoint>), typeof(DataPointAdvisor),
                new FrameworkPropertyMetadata(new ObservableCollection<DataPoint>(),
                    new PropertyChangedCallback(OnSelectedPointsChanged)));

        public static ObservableCollection<DataPoint> GetSelectedPoints(DependencyObject d)
        {
            return (ObservableCollection<DataPoint>)d.GetValue(SelectedPointsProperty);
        }

        public static void SetSelectedPoints(DependencyObject d, ObservableCollection<DataPoint> value)
        {
            d.SetValue(SelectedPointsProperty, value);
        }

        private static void OnSelectedPointsChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {

        }

        #endregion
    }
}
